<?php
namespace Teknisa\CMP\Modules\V1\Controllers; 

use Compras\Logic\Fornecimento\AutorizacaoFornecimento;
use Financeiro\Logic\ContasPagar\ContasPrevistaAF;
use Teknisa\CMP\Modules\V1\Services\AlteracaoAprovacaoAfService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Cmp07604ProdutoAf extends \Teknisa\GER\Modules\V1\Controllers\TeknisaCrud {

    protected $alteracaoAprovacaoAfService;
    protected $autorizacaoFornecimento;
    protected $contasPrevistaAF;
    protected $dataSourceName = "cmp07604_produto_af";
    protected $parameterBagColumns = array(
        "NRAUTOFORN",
        "CDFILDEST",
        "CDFILLANC",
        "NRORG"
    );

    public function __construct($dataSource, $environment, $parameterBag, AlteracaoAprovacaoAfService $alteracaoAprovacaoAfService, AutorizacaoFornecimento $autorizacaoFornecimento, ContasPrevistaAF $contasPrevistaAF){
        parent::__construct($dataSource, $environment, $parameterBag);
        $this->alteracaoAprovacaoAfService = $alteracaoAprovacaoAfService;
        $this->autorizacaoFornecimento = $autorizacaoFornecimento;
        $this->contasPrevistaAF = $contasPrevistaAF;
    }

    public function verificaProdutoFornecedor(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $result = $this->alteracaoAprovacaoAfService->verificaProdutoFornecedor($row);

            $response->addDataSet(new DataSet('fornecedor', $result));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function verificaQualificacaoMarca(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $result = $this->alteracaoAprovacaoAfService->verificaQualificacaoMarca($row);

            $response->addDataSet(new DataSet('qualificacao', $result));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function verificaProdQualificadoForn(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $result = $this->alteracaoAprovacaoAfService->verificaProdQualificadoForn($row);

            $response->addDataSet(new DataSet('prodForn', $result));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function verificaProdutoInativo(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $result = $this->alteracaoAprovacaoAfService->verificaProdutoInativo($row);

            $response->addDataSet(new DataSet('produto', $result));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function proceVerificaInconsAfs(Request\Row $request){
        try {
            $param = $request->getRow();
            $this->alteracaoAprovacaoAfService->proceVerificaInconsAfs($param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN']);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function proceImpostoItemAf(Request\Row $request){
        $param = $request->getRow();
        $this->autorizacaoFornecimento->executaProcedureImpostoItemAF($param['paramProcedure']['NRORG'], $param['paramProcedure']['CDEMPRESA'], $param['paramProcedure']['NRINSJURFORN'], $param['paramProcedure']['CDFORNECED'], $param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN'], $param['paramProcedure']['DTAUTOFORN']);
    }

    public function proceExcluiContaPagarPrevista(Request\Row $request){
        $param = $request->getRow();
        $this->contasPrevistaAF->executaExcluiContasPagarPrevista($param['paramProcedure']['NRORG'], $param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN']);
    }

    public function proceGeraContaPagarPrevista(Request\Row $request){
        $param = $request->getRow();
        $this->contasPrevistaAF->executaGeraContasPagarPrevista($param['paramProcedure']['NRORG'], $param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN']);
    }

    public function proceFechamentoAf(Request\Row $request){
        try {
            $param = $request->getRow();
            $this->alteracaoAprovacaoAfService->proceFechamentoAf($param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN']);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function proceConsisteOrcamento(Request\Row $request){
        try {
            $param = $request->getRow();
            $this->alteracaoAprovacaoAfService->proceConsisteOrcamento($param['paramProcedure']['CDFILDEST'], $param['paramProcedure']['CDFILLANC'], $param['paramProcedure']['NRAUTOFORN']);
        } catch (\Exception $e) {
            throw $e;
        }
    }

}